==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/YearToDateExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YearToDateExpressionDescription } from "./YearToDateExpressionDescription";
/**
 * @hidden
 */
export let YearToDateExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class YearToDateExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (YearToDateExpressionDescriptionMetadata.a == null) {
                YearToDateExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                YearToDateExpressionDescriptionMetadata.c(YearToDateExpressionDescriptionMetadata.a);
            }
            if (a.j(YearToDateExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(YearToDateExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            YearToDateExpressionDescriptionMetadata.b(a);
            a.aa("YearToDateExpression", () => new YearToDateExpressionDescription());
            a.z("YearToDateExpression", YearToDateExpressionDescriptionMetadata.a);
        }
    }
    YearToDateExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(YearToDateExpressionDescriptionMetadata, 'YearToDateExpressionDescriptionMetadata');
    YearToDateExpressionDescriptionMetadata.a = null;
    return YearToDateExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/YearToDateExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YearToDateExpressionDescription } from "./YearToDateExpressionDescription";
/**
 * @hidden
 */
export let YearToDateExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class YearToDateExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (YearToDateExpressionDescriptionMetadata.a == null) {
                YearToDateExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                YearToDateExpressionDescriptionMetadata.c(YearToDateExpressionDescriptionMetadata.a);
            }
            if (a.k(YearToDateExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(YearToDateExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            YearToDateExpressionDescriptionMetadata.b(a);
            a.ac("YearToDateExpression", () => new YearToDateExpressionDescription());
            a.ab("YearToDateExpression", YearToDateExpressionDescriptionMetadata.a);
        }
    }
    YearToDateExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(YearToDateExpressionDescriptionMetadata, 'YearToDateExpressionDescriptionMetadata');
    YearToDateExpressionDescriptionMetadata.a = null;
    return YearToDateExpressionDescriptionMetadata;
})();
